@@ -15,7 +15,7 @@ from cognite.client.exceptions import CogniteNotFoundError, CogniteAPIError
 from akerbp.mlops.core import logger, config
 locals().update(config.getenv)
 
-logging=logger.get_logger(name='cdf_helper')
+logging=logger.get_logger(name='mlops_cdf')
 
 global_client = {}
 api_keys=config.api_keys
