@@ -8,7 +8,7 @@ from dataclasses import asdict
 from akerbp.mlops.core import helpers 
 from akerbp.mlops.core import logger
 
-logging=logger.get_logger(name='MLOps')
+logging=logger.get_logger(name='mlops_core')
 
 
 @dataclass
@@ -45,7 +45,7 @@ _getenv=EnvVar(
     google_project_id=os.getenv('GOOGLE_PROJECT_ID')
 )
 getenv=asdict(_getenv)
-logging.debug(getenv)
+logging.debug(f"{getenv=}")
 
 @dataclass
 class CdfKeys():
