@@ -2,21 +2,24 @@
 
 import logging
 import os
+from os.path import basename
 
 default_format = '%(asctime)s - %(name)s - %(levelname)s - %(message)s'
 base_name='main'
 
 class CDFLogger:
+    def __init__(self, base_name):
+        self.base_name=base_name
     def debug(self,log):
-        print("DEBUG - " + log)
+        print(f"{self.basename}-DEBUG-{log}")
     def info(self,log):
-        print("INFO - " + log)
+        print(f"{self.basename}-INFO-{log}")
     def warning(self,log):
-        print("WARNING - " + log)
+        print(f"{self.basename}-WARNING-{log}")
     def error(self,log):
-        print("ERROR - " + log)
+        print(f"{self.basename}-ERROR-{log}")
     def critical(self,log):
-        print("CRITICAL - " + log)
+        print(f"{self.basename}-CRITICAL-{log}")
 
 
 def get_logger(name=base_name, format=default_format):
@@ -25,7 +28,7 @@ def get_logger(name=base_name, format=default_format):
     """
     
     if not os.getenv('COGNITE_API_KEY_FUNCTIONS'): #hacky test for CDF environm.
-        return CDFLogger()
+        return CDFLogger(base_name)
     
     logger = logging.getLogger(name)
     logger.setLevel(logging.DEBUG)
