@@ -11,7 +11,7 @@ import shutil
 import akerbp.mlops.model_manager as mm
 from akerbp.mlops.deployment import helpers
 from akerbp.mlops.core import logger, config
-logging=logger.get_logger(name='MLOps')
+logging=logger.get_logger(name='mlops_deployment')
 locals().update(config.getenv)
 
 
