@@ -12,7 +12,7 @@ from pydantic import Json, BaseModel
 
 from akerbp.mlops.gc.helpers import access_secret_version
 from akerbp.mlops.core import config, logger
-logging=logger.get_logger()
+logging=logger.get_logger("mlops_gc")
 locals().update(config.getenv)
 
 service = import_module(f"akerbp.mlops.services.{service_name}").service
