@@ -15,7 +15,7 @@ import json
 
 from akerbp.mlops.core import config, logger 
 locals().update(config.getenv)
-logging=logger.get_logger(name='gc_helper')
+logging=logger.get_logger(name='mlops_gc')
 
 
 
