@@ -8,7 +8,7 @@ import sys
 from importlib import import_module
 
 from akerbp.mlops.core import config, logger
-locals().update(config.getenv.__dict__)
+locals().update(config.getenv)
 logging=logger.get_logger(name='MLOps')
 
 
